# 'testypiymkarakula' - My simple Project

* opt1
* opt2
* opt3

## install

```python
pip install testpypimkarakula
```

### Usage

```python
from testpypimkarakula.m_mod_mkarakula import name as mk
from testpypimkarakula.m_mod_mkarakula import get_numpy
>>> n("Name","Surname")
Name Surname
>>> get_numpy([1,2,3,4,5])
[1 2 3 4 5]
```